Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(888)

Unified Diff: chrome/browser/ui/website_settings/website_settings.h

Issue 2327433002: Stop using CertStore which is not compatible with PlzNavigate. (Closed)
Patch Set: remove cert_store on ios Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/website_settings/website_settings.h
diff --git a/chrome/browser/ui/website_settings/website_settings.h b/chrome/browser/ui/website_settings/website_settings.h
index 28d80ff3319ca1aa6670b70540e5991796fcd5dc..bfa853740267b146d7af7e28939d42ea8560d4da 100644
--- a/chrome/browser/ui/website_settings/website_settings.h
+++ b/chrome/browser/ui/website_settings/website_settings.h
@@ -14,10 +14,13 @@
#include "url/gurl.h"
namespace content {
-class CertStore;
class WebContents;
}
+namespace net {
+class X509Certificate;
+}
+
class ChromeSSLHostStateDelegate;
class ChooserContextBase;
class HostContentSettingsMap;
@@ -115,8 +118,7 @@ class WebsiteSettings : public TabSpecificContentSettings::SiteDataObserver {
TabSpecificContentSettings* tab_specific_content_settings,
content::WebContents* web_contents,
const GURL& url,
- const security_state::SecurityStateModel::SecurityInfo& security_info,
- content::CertStore* cert_store);
+ const security_state::SecurityStateModel::SecurityInfo& security_info);
~WebsiteSettings() override;
void RecordWebsiteSettingsAction(WebsiteSettingsAction action);
@@ -191,9 +193,8 @@ class WebsiteSettings : public TabSpecificContentSettings::SiteDataObserver {
// Status of the website's identity verification check.
SiteIdentityStatus site_identity_status_;
- // For secure connection |cert_id_| is set to the ID of the server
- // certificate. For non secure connections |cert_id_| is 0.
- int cert_id_;
+ // For secure connection |certificate_| is set to the server certificate.
+ scoped_refptr<net::X509Certificate> certificate_;
// Status of the connection to the website.
SiteConnectionStatus site_connection_status_;
@@ -226,9 +227,6 @@ class WebsiteSettings : public TabSpecificContentSettings::SiteDataObserver {
// the UI.
base::string16 organization_name_;
- // The |CertStore| provides all X509Certificates.
- content::CertStore* cert_store_;
-
// The |HostContentSettingsMap| is the service that provides and manages
// content settings (aka. site permissions).
HostContentSettingsMap* content_settings_;

Powered by Google App Engine
This is Rietveld 408576698